@@ -16,10 +16,7 @@
 #'
 #' @examples
 #' compute_residuals(dax_model_3t)
-#' res <- residuals(dax_model_3t)
-#' summary(res)
-#' 
-#' @importFrom stats pt pgamma qnorm
+#' summary(residuals(dax_model_3t))
 
 compute_residuals <- function(x, verbose = TRUE) {
 
@@ -42,29 +39,40 @@ compute_residuals <- function(x, verbose = TRUE) {
   }
 
   ### function that computes the residuals
-  cr <- function(data, mus, sigmas, dfs, sdd_name, decoding) {
+  cr <- function(data, mu, sigma, df, sdd_name, decoding) {
     stopifnot(length(data) == length(decoding))
     out <- rep(NA_real_, length(data))
     for (t in seq_along(data)) {
       if (sdd_name == "t") {
         Fxt <- stats::pt(
-          q = (data[t] - mus[decoding[t]]) / sigmas[decoding[t]],
-          df = dfs[decoding[t]]
+          q = (data[t] - mu[decoding[t]]) / sigma[decoding[t]],
+          df = df[decoding[t]]
         )
-      }
-      if (sdd_name == "gamma") {
+      } else if (sdd_name == "gamma") {
         Fxt <- stats::pgamma(
           q = data[t],
-          shape = mus[decoding[t]]^2 / sigmas[decoding[t]]^2,
-          scale = sigmas[decoding[t]]^2 / mus[decoding[t]]
+          shape = mu[decoding[t]]^2 / sigma[decoding[t]]^2,
+          scale = sigma[decoding[t]]^2 / mu[decoding[t]]
         )
-      }
-      if (sdd_name == "lnorm") {
+      } else if (sdd_name == "lognormal") {
         Fxt <- stats::plnorm(
           q = data[t],
-          meanlog = mus[decoding[t]],
-          sdlog = sigmas[decoding[t]]
+          meanlog = mu[decoding[t]],
+          sdlog = sigma[decoding[t]]
         )
+      } else if (sdd_name == "normal") {
+        Fxt <- stats::pnorm(
+          q = data[t],
+          mean = mu[decoding[t]],
+          sd = sigma[decoding[t]]
+        )
+      } else if (sdd_name == "poisson") {
+        Fxt <- stats::ppois(
+          q = data[t],
+          lambda = mu[decoding[t]]
+        )
+      } else {
+        stop("Unknown state-dependent distribution", call. = FALSE)
       }
       out[t] <- stats::qnorm(Fxt)
     }
@@ -75,16 +83,16 @@ compute_residuals <- function(x, verbose = TRUE) {
   par <- parUncon2par(x$estimate, x$data$controls)
   if (!x$data$controls$hierarchy) {
     residuals <- cr(
-      data = x$data$data, mus = par$mus, sigmas = par$sigmas,
-      dfs = par$dfs, sdd_name = x$data$controls$sdds[[1]]$name,
+      data = x$data$data, mu = par$mu, sigma = par$sigma,
+      df = par$df, sdd_name = x$data$controls$sdds[[1]]$name,
       decoding = x$decoding
     )
   } else {
     residuals <- matrix(NA_real_, nrow = nrow(x$data$data), 
                         ncol = ncol(x$data$data))
     residuals[, 1] <- cr(
-      data = x$data$data[, 1], mus = par$mus,
-      sigmas = par$sigmas, dfs = par$dfs,
+      data = x$data$data[, 1], mu = par$mu,
+      sigma = par$sigma, df = par$df,
       sdd_name = x$data$controls$sdds[[1]]$name,
       decoding = x$decoding[, 1]
     )
@@ -92,9 +100,9 @@ compute_residuals <- function(x, verbose = TRUE) {
       curr <- x$decoding[t, 1]
       residuals[t, -1] <- cr(
         data = x$data$data[t, -1],
-        mus = par$mus_star[[curr]],
-        sigmas = par$sigmas_star[[curr]],
-        dfs = par$dfs_star[[curr]],
+        mu = par$mu_star[[curr]],
+        sigma = par$sigma_star[[curr]],
+        df = par$df_star[[curr]],
         sdd_name = x$data$controls$sdds[[2]]$name,
         decoding = x$decoding[t, -1]
       )
