@@ -18,8 +18,8 @@ dax_model_3t <- decode_states(dax_model_3t)
 ## ----decoded-ts---------------------------------------------------------------
 plot(dax_model_3t)
 
-## ----reorder------------------------------------------------------------------
-dax_model_3t <- reorder_states(dax_model_3t, 3:1)
+## ----reorder, eval = FALSE----------------------------------------------------
+#  dax_model_3t <- reorder_states(dax_model_3t, 3:1)
 
 ## ----predict------------------------------------------------------------------
 predict(dax_model_3t, ahead = 10)
