@@ -4,7 +4,7 @@ test_that("ci computation works", {
   expect_error(compute_ci(dax_model_3t, -1))
   expect_error(compute_ci(dax_model_3t, 2))
   dax_model_3t_tmp <- dax_model_3t
-  dax_model_3t_tmp$hessian[1,1] <- Inf
+  dax_model_3t_tmp$inverse_fisher[3] <- -1
   suppressWarnings(expect_warning(compute_ci(dax_model_3t_tmp)))
   ci <- compute_ci(x = dax_model_3t, alpha = 0.05)
   expect_type(ci, "list")
